AmazonConfig

Struct AmazonConfig 

pub struct AmazonConfig { /* private fields */ }
if we provide this struct, we need all three fields.

if this is provided, we will fuse epoch1file and epoch2fle into the resulting txfile

Implementations

Source

impl AmazonConfig

pub fn txfile(&self) -> &String

txfile specifies a CSV file (to be generated)

each row will be deserialized from an AmazonTx

pub fn epoch1file(&self) -> &String

epoch1file should specify a CSV file where the fields deserialize from an AmazonTx1

pub fn epoch2file(&self) -> &String

epoch2file should specify a CSV file where the fields deserialize from an AmazonTx2